#!/bin/csh                    
#SBATCH -J c221           # Job name
#SBATCH -o c221.o%j        # output and error file name (%j expands to jobID)
#SBATCH -N 1             # total number of nodes
#SBATCH -n 4            # total number of cores
#SBATCH -p normal              # queue (partition) -- normal, development, etc. 
#SBATCH -t 48:00:00            # run time (hh:mm:ss)



module load intel/16.0.3 impi namd/2.12

cd $SLURM_SUBMIT_DIR



# Set Run Length per file
set simt = 5000000

echo Running on host `hostname`
echo Time is `date`
echo Directory is `pwd`
echo This jobs runs on the following processors:


@ krun = 1

if ( -e start.time) then
 @ start = `cat start.time `
else
 @ start = 0
endif

# Create a new input file
rm -f dyn.inp
cat dyn-1.inp > dyn.inp
echo "firsttimestep     $start; " >> dyn.inp
cat dyn-2.inp >> dyn.inp

# Execution of the script $BINDIR/namd2 +com
ibrun namd2 +ppn 32 +pemap 0-63+68 +commap 64-67 dyn.inp >& dyn.out

set okay = true
# TEST FOR EXISTENCE, THEN NONZERO LENGTH OF OUTPUT FILES
if ( -e dyn.coor && -e dyn.dcd ) then
 @ tsz = `/bin/ls -s dyn.dcd | awk '{print $1}'`
 @ nrm = `grep 'WallClock' dyn.out | wc -l`
 if ( $tsz > 0 && $nrm == 1 ) then
# SUCCESSFUL RUN; COPY RESTART FILE
#  cp dyn.res dyn.rea
# DETERMINE RUN NUMBER
  if ( -e next.seqno ) then
   @ i = `cat next.seqno`
  else
   @ i = 1
  endif
# Change the new Start Time
@ start = $start + $simt
echo $start > start.time

# ENABLE/DISABLE ANALYSIS EVERY 2ND RUN
#  if ( 0 == $i % 2 ) qsub -l nodes=1 chk.csh
# NUMBER THE OUTPUT FILES; CHANGE EXTENSIONS TO SUIT APPLICATION
  foreach fil ( out coor xsc xst vel dcd )
   mv dyn.$fil dyn$i.$fil
  end
  cp dyn$i.xsc dyn.xsc
  cp dyn$i.coor dyn.coor
  cp dyn$i.vel dyn.vel
  gzip dyn$i.out dyn$i.coor dyn$i.xsc dyn$i.vel dyn$i.xst
# CONDITIONAL END CHECK
  if ( -e last.seqno ) then
    @ l = `cat last.seqno`
    if ( $i == $l ) then
      @ i += 1
      echo $i > next.seqno
      exit
    endif
  endif

# SUBMIT THE NEXT JOB
#  rm ~/namd.$PBS_JOBID
  sleep 5m
  @ i += 1
  echo $i > next.seqno

ssh login1 /work/04431/ewang125/stampede2/sc/cer26/cer2-20/1/namd/dyn.scr

  exit
else
# FILE DOESN'T EXIST
 set okay = false
endif
# FILE DOESN'T EXIST
 set okay = false
endif

# TEST FOR CHARMM RUN FAILED; CREATE .ERR FILE WITH TIMESTAMP
if ( $okay == false ) then
 set ts = `date +%m%d.%H%M`
 mv dyn.out dyn.err.$ts
 exit(201)
endif
